package com.lantone.qc.kernel.catalogue.behospitalized;

import com.google.common.collect.Lists;
import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.entity.Diag;
import com.lantone.qc.pub.model.label.PastLabel;
import com.lantone.qc.pub.util.ListUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @Description: 疾病名未标引号
 * @author: rengb
 * @time: 2020/3/10 14:02
 */
@Component
public class BEH0032 extends QCCatalogue {

    @Override
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status = "0";
        PastLabel pastLabel = inputInfo.getBeHospitalizedDoc().getPastLabel();
        List<Diag> diags = pastLabel.getDiags();
        if (ListUtil.isEmpty(diags)) {
            return;
        }
        String pastLabelText = pastLabel.getText();
        List<String> yinxDiagNames = diags.stream().filter(i -> i.getNegative() != null).map(i -> i.getName()).collect(Collectors.toList());
        List<String> yangxDiagNams = diags.stream().filter(i -> i.getNegative() == null).map(i -> i.getName()).collect(Collectors.toList());
        if (isNotHas(yinxDiagNames, pastLabelText) || isNotHas(yangxDiagNams, pastLabelText)) {
            status = "-1";
        }
    }

    /**
     * 是未标引号吗？
     *
     * @param diagNames ture-是未标  false-标了
     * @return
     */
    private boolean isNotHas(List<String> diagNames, String pastLabelText) {
        boolean flag = false;
        if (ListUtil.isNotEmpty(diagNames)) {
            List<String> sections = Lists.newArrayList();
            int index = 0;
            for (String txt : pastLabelText.split("\"")) {
                if (index % 2 == 1) {
                    sections.add(txt);
                }
                index++;
            }
            for (String diagName : diagNames) {
                if (sections.stream().filter(section -> section.indexOf(diagName) != -1).count() == 0) {
                    flag = true;
                    info += diagName + " ";
                }
            }
        }
        return flag;
    }

}